=======
Credits
=======

Development Lead
----------------

* Henrik Blidh <henrik.blidh@nedomkull.com>

Development Team / Collaborators
--------------------------------

* David Lechner <david@pybricks.com>

Contributors
------------

* Chad Spensky <chad@allthenticate.net>
* Bernie Conrad <bernie@allthenticate.net>
* Jonathan Soto <jsotogaviard@alum.mit.edu>
* Kyle J. Williams <kyle@kjwill.tech>
